pub struct narenas;Expand description
Maximum number of arenas to use for automatic multiplexing of threads and arenas.
The default is four times the number of CPUs, or one if there is a single CPU.
Examples
use tikv_jemalloc_ctl::opt;
let narenas = opt::narenas::read().unwrap();
println!("number of arenas: {}", narenas);Implementations