pub struct tcache;Expand description
Thread-local allocation caching behavior.
Thread-specific caching allows many allocations to be satisfied without performing any thread synchronization, at the cost of increased memory use. This is enabled by default.
Examples
use tikv_jemalloc_ctl::opt;
let tcache = opt::tcache::read().unwrap();
println!("thread-local caching: {}", tcache);Implementations