active

Struct active 

pub struct active;
Total number of bytes in active pages allocated by the application.

This is a multiple of the page size, and greater than or equal to the value returned by allocated.

This statistic is cached, and is only refreshed when the epoch is advanced. See the crate::epoch type for more information.

This corresponds to stats.active in jemalloc’s API.

Examples

use tikv_jemalloc_ctl::{epoch, stats};
let e = epoch::mib().unwrap();
let active = stats::active::mib().unwrap();

let a = active.read().unwrap();
let _buf = vec![0; 1024 * 1024];
e.advance().unwrap();
let b = active.read().unwrap();
assert!(a < b);

Implementations

Source

impl active

pub fn mib() -> Result<active_mib>

Returns Management Information Base (MIB)

This value can be used to access the key without doing string lookup.

pub fn name() -> &'static Name

Source

impl active

pub fn read() -> Result<size_t>

Reads value using string API.