epoch

Struct epoch 

pub struct epoch;
jemalloc epoch.

Many of the statistics tracked by jemalloc are cached. The epoch controls when they are refreshed. Both write and update are the same as calling advance() and ignore any provided value.

Example

Advancing the epoch:

use tikv_jemalloc_ctl::epoch;
let e = epoch::mib().unwrap();
let a = e.advance().unwrap();
let b = e.advance().unwrap();
assert_eq!(a + 1, b);

let o = e.update(0).unwrap();
assert_eq!(o, e.read().unwrap());

Implementations

Source

impl epoch

pub fn mib() -> Result<epoch_mib>

Returns Management Information Base (MIB)

This value can be used to access the key without doing string lookup.

pub fn name() -> &'static Name

Source

impl epoch

pub fn read() -> Result<u64>

Reads value using string API.

Source

impl epoch

pub fn write(value: u64) -> Result<()>

Writes value using string API.

Source

impl epoch

pub fn update(value: u64) -> Result<u64>

Updates key to value returning its old value using string API.

Source

impl epoch

pub fn advance() -> Result<u64>

Advances the epoch returning its latest value - see epoch.