#[repr(transparent)]
pub struct Name(_);
A Name in the MALLCTL NAMESPACE.
Returns the MibStr of self which is a key whose value is a string.
Returns true if self is a key in the MALLCTL NAMESPCE referring to
a null-terminated string.
Returns the name as null-terminated byte-string.
Read the key at self.
Write value at the key self.
Write value at the key self returning its previous value.
Read the key at self.
Write value at the key self.
Write value at the key self returning its previous value.
Read the key at self.
Write value at the key self.
Write value at the key self returning its previous value.
Read the key at self.
Write value at the key self.
Write value at the key self returning its previous value.
Read the key at self.
Write value at the key self.
Write value at the key self returning its previous value.
Read the key at self.
Write value at the key self.
Write value at the key self returning its previous value.
Read the key at self.
Write value at the key self.
Write value at the key self returning its previous value.
Formats the value using the given formatter.
Read more
Formats the value using the given formatter.
Read more
This method tests for self and other values to be equal, and is used
by ==.
This method tests for !=. The default implementation is almost always
sufficient, and should not be overridden without very good reason.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more